# JWT Auth React

![npm](https://img.shields.io/npm/v/jwt-auth-react?logo=npm&style=flat-square)
![npm bundle size](https://img.shields.io/bundlephobia/minzip/jwt-auth-react?logo=npm&style=flat-square)
![npm](https://img.shields.io/npm/dw/jwt-auth-react?logo=npm&style=flat-square)
![GitHub top language](https://img.shields.io/github/languages/top/darkmatter18/jwt-auth-react?logo=typescript&style=flat-square)
![dependencies](https://img.shields.io/david/darkmatter18/jwt-auth-react?style=flat-square)
![GitHub License](https://img.shields.io/github/license/darkmatter18/jwt-auth-react?logo=apache&style=flat-square)

React [Context](https://reactjs.org/docs/context.html) and [Hooks](https://reactjs.org/docs/hooks-intro.html) 
based `Authentication` Package for [React](https://reactjs.org/) Apps

## Installation

Install the `jwt-auth-react` as a dependency in your React app.

```cmd
npm install jwt-auth-react
```

This will install the package and will create an entry in your App's `package.json` file

## Usage

#### 1. AuthProvider

`AuthProvider` relies on the [context feature of React](https://reactjs.org/docs/context.html) to pass the `Auth` down 
to the components, so you need to make sure that `AuthProvider` is a parent of the `Routing components`.
You can learn more about this in the API section.

```jsx
import {AuthProvider} from "jwt-auth-react";

...

<AuthProvider>
    <RouteComponent />
</AuthProvider>
```

#### 2. PrivateRoute
`PrivateRoute` relies on [react-router-dom](https://reacttraining.com/react-router) same as the 
[`Route` component of React Router](https://reacttraining.com/react-router/web/api/Route). 
It creates a Route to an `Authentication` based component.
If the user is not authenticated, it will redirect to `login` Page.
You can learn more about this in the API section.

```jsx
import {BrowserRouter, Route} from "react-router-dom";
import {PrivateRoute} from "jwt-auth-react";

...

<BrowserRouter>
    <Route component={LoginComponent} path={LOGIN_URL} exact/>
    ...
    <PrivateRoute component={DashboardComponent} path={DASHBOARD_URL} loginPath={LOGIN_URL}/>
</BrowserRouter>
```

#### 3. loginAuth
`loginAuth` is a function api, relies on [React Hooks](https://reactjs.org/docs/hooks-intro.html).
It logs in the user and stores the `JWT token` and `expiresIn` time `in minutes`.
Impliment the `loginAuth` function on login pipeline i.e in `login api response`.
You can learn more about this in the API section.

Example with `fetch`:
```jsx
import {loginAuth} from "jwt-auth-react";

const do_login = async () => {
    const res = await fetch("https://api.abc.xyz/login");
    if (res.status === 200){
        const res_json = res.json()   
        const jit_token = res_json.jit;
        const expiresIn = res_json.expiresIn;
        loginAuth(token = jit_token, expiresIn = expiresIn);
    }
}
```

Example with `axios`:
```jsx
import axios from 'axios'
import {loginAuth} from "jwt-auth-react";

const do_login = async () => {
    const res = await axios.post("https://api.abc.xyz/login");
    if (res.status === 200){
        const res_json = res.data;   
        const jit_token = res_json.jit;
        const expiresIn = res_json.expiresIn;
        loginAuth(token = jit_token, expiresIn = expiresIn);
    }
}
```

#### 4. logoutAuth

`logoutAuth` is a function api, relies on [React Hooks](https://reactjs.org/docs/hooks-intro.html).
It logouts the current user and clear all token.
Impliment the `logoutAuth` function on logout pipeline ex. *on Logout Button Click*.
You can learn more about this in the API section.

```jsx
import react from 'react';
import {logoutAuth} from "jwt-auth-react";

const logoutComponent = () => {
    const logoutPipeline = () => {
        logoutAuth()
    }
    return <button onClick={logoutPipeline}>Logout</button>
}
```
#### 5. authHeader
`logoutAuth` is a function api. It produces the `authentication header` string for logged in user.

It returns `Bearer: xxxxxx` string

Example with `fetch`:
```jsx
import {authHeader} from "jwt-auth-react";

const do_something = async () => {
    const myInit = {
        method: 'GET',
        headers: {
            'Authentication': authHeader()
        }
    }
    const res = await fetch("https://api.abc.xyz/something", myInit);
    
    if (res.status === 200){
        const res_json = res.json()   
        ...
    }
}
```

Example with `axios`:
```jsx
import axios from "axios";
import {authHeader} from "jwt-auth-react";

const do_something = async () => {
    const res = await axios.get("https://api.abc.xyz/something", 
        headers: {
            'Authentication': authHeader()
        });
    if (res.status === 200){
        const res_json = res.json()   
        ...
    }
}
```

## Maintainer

[![Relative date](https://img.shields.io/date/1590132490?color=important&label=started&logo=github&style=flat-square)](https://github.com/darkmatter18/) [![Maintenance](https://img.shields.io/maintenance/yes/2020?color=green&logo=github&style=flat-square)](https://github.com/darkmatter18/)

[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/0)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/0)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/1)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/1)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/2)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/2)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/3)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/3)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/4)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/4)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/5)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/5)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/6)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/6)[![](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/images/7)](https://sourcerer.io/fame/darkmatter18/darkmatter18/jwt-auth-react/links/7)
**[Arkadip Bhattacharya](https://www.linkedin.com/in/arkadip/)**

<a href="https://twitter.com/Arkadipb21"><img src="images/twitter.png" width="32px" height="32px"></a> <a href="https://www.facebook.com/arkadipb"><img src="images/facebook.png" width="32px" height="32px"></a> <a href="https://www.linkedin.com/in/arkadip/"><img src="images/linkedin.png" width="32px" height="32px"></a>

> ***Need help?***
***Feel free to contact me @ [in2arkadipb13@gmail.com](mailto:in2arkadipb13@gmail.com?Subject=Github:Udacity-Computer-Vision-Nanodegree-Repository)***

[![GitHub followers](https://img.shields.io/github/followers/darkmatter18?color=1e88e5&label=Follow%20%40darkmatter18&logo=github&style=flat-square)](https://github.com/darkmatter18/) [![Twitter Follow](https://img.shields.io/twitter/follow/Arkadipb21?color=1e88e5&logo=twitter&style=flat-square)](https://twitter.com/Arkadipb21) 

[![LOVE](https://forthebadge.com/images/badges/built-with-love.svg)]()
[![FOR YOU](https://forthebadge.com/images/badges/for-you.svg)]()
[![BY DEVELOPERS](https://forthebadge.com/images/badges/built-by-developers.svg)]()